@@ -42,7 +42,7 @@
 #include "gpgtar.h"
 
 #ifndef HAVE_LSTAT
-#define lstat(a,b) stat ((a), (b))
+#define lstat(a,b) gnupg_stat ((a), (b))
 #endif
 
 
@@ -148,7 +148,7 @@ fillup_entry_w32 (tar_header_t hdr)
 
   /* Only set the size for a regular file.  */
   if (hdr->typeflag == TF_REGULAR)
-    hdr->size = (fad.nFileSizeHigh * (unsigned long long)(MAXDWORD+1)
+    hdr->size = (fad.nFileSizeHigh * ((unsigned long long)MAXDWORD+1)
                  + fad.nFileSizeLow);
 
   hdr->mtime = (((unsigned long long)fad.ftLastWriteTime.dwHighDateTime << 32)
@@ -301,6 +301,8 @@ scan_directory (const char *dname, scanctrl_t scanctrl)
   gpg_error_t err = 0;
 
 #ifdef HAVE_W32_SYSTEM
+  /* Note that we introduced gnupg_opendir only after we had deployed
+   * this code and thus we don't change it for now.  */
   WIN32_FIND_DATAW fi;
   HANDLE hd = INVALID_HANDLE_VALUE;
   char *p;
